{% load i18n %}


<h3>{% blocktrans with filter_title=title %} By {{ filter_title }} {% endblocktrans %}</h3>
<ul>
	{% if choices|slice:"4:" %}
		<li>
			<select style="width: 95%;" {# onchange="go_from_select(this.options[this.selectedIndex].value)" #} >
				{% for choice in choices %}<option{% if choice.selected %} selected="selected"{% endif %} value="{{ choice.query_string|iriencode }}">{{ choice.display }}</option>{% endfor %}
			</select>
		</li>
	{% else %}
		{% for choice in choices %}
			<li{% if choice.selected %} class="selected"{% endif %}>
				<a href="{{ choice.query_string|iriencode }}">{{ choice.display }}</a>
			</li>
		{% endfor %}
	{% endif %}
</ul>
